@@ -10,7 +10,7 @@ extern crate scan_fmt;
 #[macro_use]
 extern crate maplit;
 
-pub mod az_lmdb;
+pub mod az_impl;
 pub mod ft_xapian;
 pub mod module;
 pub mod onto;
@@ -19,4 +19,4 @@ pub mod storage;
 pub mod v_api;
 
 pub use v_authorization;
-pub use v_queue;
\ No newline at end of file
+pub use v_queue;
